#######################################################
# PROGRAM: AngristLavy_Table4
# PURPOSE: Recreates Table 4 of Angrist and Lavy (1999)
#######################################################
library(foreign) 

# 第5学年データを読み込み
df.5 <- read.dta("final5.dta")

# データ整理
df.5$avgmath <- ifelse(df.5$avgmath>100, df.5$avgmath-100, df.5$avgmath) 
df.5$avgverb <- ifelse(df.5$avgverb>100, df.5$avgverb-100, df.5$avgverb) 

df.5$avgverb[df.5$verbsize==0]  <- NA
df.5$passverb[df.5$verbsize==0] <- NA
df.5$avgmath[df.5$mathsize==0]  <- NA
df.5$passmath[df.5$mathsize==0] <- NA

df.5.2 <- df.5[1 < df.5$classize & df.5$classize < 45 & df.5$c_size >5,]
df.5.2 <- df.5.2[df.5.2$c_leom ==1 & df.5.2$c_pik <3,]

# クラスサイズ関数による予測値計算
df.5.2$func1 <- df.5.2$c_size/(as.integer( (df.5.2$c_size-1)/40)+1) 
df.5.2$func2 <- df.5.2$cohsize/(as.integer(df.5.2$cohsize/40)+1)

# Discontinuity サンプルの判定用変数
df.5.2$disc <- ifelse( (df.5.2$c_size>=36 & df.5.2$c_size<=45) | (df.5.2$c_size>=76 & df.5.2$c_size<=85) | 
                         (df.5.2$c_size>=116 & df.5.2$c_size<=125),T,F)

# クラスサイズ2乗項
df.5.2$c_size2 <- df.5.2$c_size^2/100

# トレンド項作成
df.5.2$trend <- ifelse(0  <= df.5.2$c_size & df.5.2$c_size <=40,  df.5.2$c_size, NA)
df.5.2$trend <- ifelse(41 <= df.5.2$c_size & df.5.2$c_size <=80,  df.5.2$c_size/2 + 20, df.5.2$trend)
df.5.2$trend <- ifelse(81 <= df.5.2$c_size & df.5.2$c_size <=120, df.5.2$c_size/3 + 100/3, df.5.2$trend)
df.5.2$trend <- ifelse(121<= df.5.2$c_size & df.5.2$c_size <=160, df.5.2$c_size/4 + 130/3, df.5.2$trend)

### データセット作成ここまで ###

install.packages("AER")
install.packages("ivpack")
library(AER)
library(ivpack) 

#COL 1
summary(lm.df.5.2.C1 <- ivreg(avgverb ~ classize + tipuach| func1 + tipuach, data=df.5.2))
res.se.C1 <- cluster.robust.se(lm.df.5.2.C1, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgverb"])])
res.se.C1

#COL 2
summary(lm.df.5.2.C2 <- ivreg(avgverb ~ classize + tipuach + c_size| func1 + tipuach + c_size, data=df.5.2))
res.se.C2 <- cluster.robust.se(lm.df.5.2.C2, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgverb"])])
res.se.C2

#COL 3
summary(lm.df.5.2.C3 <- ivreg(avgverb ~ classize + tipuach + c_size + c_size2| func1 + tipuach + c_size + c_size2, data=df.5.2))
res.se.C3 <- cluster.robust.se(lm.df.5.2.C3, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgverb"])])
res.se.C3

#COL 4
summary(lm.df.5.2.C4 <- ivreg(avgverb ~ classize + trend| func1 + trend, data=df.5.2))
res.se.C4 <- cluster.robust.se(lm.df.5.2.C4, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"trend"]) & !is.na(df.5.2[,"avgverb"])])
res.se.C4

#COL 5
summary(lm.df.5.2.C5 <- ivreg(avgverb ~ classize + tipuach | func1 + tipuach, data=df.5.2, subset=df.5.2$disc) )
res.se.C5 <- cluster.robust.se(lm.df.5.2.C5, clusterid = df.5.2$schlcode[df.5.2$disc])
res.se.C5

#COL 6
summary(lm.df.5.2.C6 <- ivreg(avgverb ~ classize + tipuach  + c_size| func1 + tipuach + c_size, data=df.5.2, subset=df.5.2$disc) )
res.se.C6 <- cluster.robust.se(lm.df.5.2.C6, clusterid = df.5.2$schlcode[df.5.2$disc])
res.se.C6

#COL 7
summary(lm.df.5.2.C7 <- ivreg(avgmath ~ classize + tipuach| func1 + tipuach, data=df.5.2))
res.se.C7 <- cluster.robust.se(lm.df.5.2.C7, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgmath"])])
res.se.C7

#COL 8
summary(lm.df.5.2.C8 <- ivreg(avgmath ~ classize + tipuach + c_size| func1 + tipuach + c_size, data=df.5.2))
res.se.C8 <- cluster.robust.se(lm.df.5.2.C8, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgmath"])])
res.se.C8

#COL 9
summary(lm.df.5.2.C9 <- ivreg(avgmath ~ classize + tipuach + c_size + c_size2| func1 + tipuach + c_size + c_size2, data=df.5.2))
res.se.C9 <- cluster.robust.se(lm.df.5.2.C9, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"avgmath"])])
res.se.C9

#COL 10
summary(lm.df.5.2.C10 <- ivreg(avgmath ~ classize + trend| func1 + trend, data=df.5.2))
res.se.C10 <- cluster.robust.se(lm.df.5.2.C10, clusterid = df.5.2$schlcode[!is.na(df.5.2[,"trend"]) & !is.na(df.5.2[,"avgmath"])])
res.se.C10

#COL 11
summary(lm.df.5.2.C11 <- ivreg(avgmath ~ classize + tipuach | func1 + tipuach, data=df.5.2, subset=df.5.2$disc) )
res.se.C11 <- cluster.robust.se(lm.df.5.2.C11, clusterid = df.5.2$schlcode[df.5.2$disc])
res.se.C11

#COL 12
summary(lm.df.5.2.C12 <- ivreg(avgmath ~ classize + tipuach  + c_size| func1 + tipuach + c_size, data=df.5.2, subset=df.5.2$disc) )
res.se.C12 <- cluster.robust.se(lm.df.5.2.C12, clusterid = df.5.2$schlcode[df.5.2$disc])
res.se.C12
